# variables that need to be passed from R:

# y = dependent
# X = fixed predictor matrix

# n = number of data points
# P = number of fixed effects

# r1.cluster.i = cluster index for random effect 1 
# r1.cluster.n = number of clusters for random effect 1 

# r2.cluster.i = cluster index for random effect 2
# r2.cluster.n = number of clusters for random effect 2

# r1.b0.mu & r2.b0.mu is set to zero –> assuming b0 in fixed model


model {
	
	# model
	
	for (i in 1:n) {
		
		y[i] ~ dnorm(y.hat[i], y.tau)
		
		y.hat[i] <- fixed[i] + random1[i] + random2[i]
		
		random1[i] <- r1.b0[r1.cluster.i[i]]
		random2[i] <- r2.b0[r2.cluster.i[i]]
		fixed[i] <- inprod(b[1:P], X[i,1:P])
		
		}
	
	
	# error term y		

	y.tau <- pow(y.noise, -2)
	y.noise ~ dunif(0, 100)
	
	
	# setting up random effect 1
	
	for (j in 1:r1.cluster.n) {
		
		r1.b0[j] ~ dnorm(r1.b0.mu, r1.b0.tau)
		r1.b0.hat[j] <- r1.b0.mu

		}
		
	#r1.b0.mu ~ dnorm(0, .0001) 
	r1.b0.mu <- 0
	r1.b0.tau <- pow(r1.b0.noise, -2) 
	r1.b0.noise ~ dunif(0, 100)
	
	
	# setting up random effect 2
	
	for (j in 1:r2.cluster.n) {
		
		r2.b0[j] ~ dnorm(r2.b0.mu, r2.b0.tau)
		r2.b0.hat[j] <- r2.b0.mu

		}
		
	#r2.b0.mu ~ dnorm(0, .0001) 
	r2.b0.mu <- 0
	r2.b0.tau <- pow(r2.b0.noise, -2) 
	r2.b0.noise ~ dunif(0, 100)
	
	
	# priors for fixed effects
	
	for (f in 1:P) {   b[f] ~ dnorm(0, .0001)   }

}