# variables that need to be passed from R:

# y = dependent
# X = fixed predictor matrix

# n = number of data points
# P = number of fixed effects

# r1.cluster.i = cluster index for random effect 1 
# r1.cluster.n = number of clusters for random effect 1 
# r1.p = number of predictors for random effect 1 

# r1.B.hat is set to zero –> assuming b0 in fixed model

# r2.cluster.i = cluster index for random effect 1 
# r2.cluster.n = number of clusters for random effect 1 
# r2.p = number of predictors for random effect 1 

# r2.B.hat is set to zero –> assuming b0 in fixed model


model {
	
	# model
	
	for (i in 1:n) {
		
		y[i] ~ dnorm(y.hat[i], y.tau)
		
		y.hat[i] <- random1[i] + random2[i] + fixed[i]
		
		random1[i] <- r1.b0[r1.cluster.i[i]] + r1.b1[r1.cluster.i[i]] * r1.x1[i]
		random2[i] <- r2.b0[r2.cluster.i[i]] + r2.b1[r2.cluster.i[i]] * r2.x1[i]
		
		fixed[i] <- inprod(b[1:P], X[i,1:P])
		
		}
		
	
	# error term y		

	y.tau <- pow(y.noise, -2)
	y.noise ~ dunif(0, 100)
	
	
	# setting up random effects 1	
	
	for (j in 1:r1.cluster.n) {
		
		r1.B[j,1:r1.p] ~ dmnorm(r1.B.hat[j,], r1.B.tau[,])
		
		r1.b0[j] <- r1.B[j,1]
		r1.b1[j] <- r1.B[j,2]
		
		for(k in 1:r1.p) {   r1.B.hat[j,k] <- 0   }

		}
	
	# model correlation between random effects
	
	r1.B.tau[1:r1.p,1:r1.p] <- inverse(r1.B.noise[,])
	
	r1.B.noise[1,1] <- pow(r1.b0.noise, 2)
	r1.B.noise[2,2] <- pow(r1.b1.noise, 2)
	
	r1.B.noise[1,2] <- r1.rho * r1.b0.noise * r1.b1.noise
	r1.B.noise[2,1] <- r1.rho * r1.b0.noise * r1.b1.noise	
	
	r1.rho ~ dunif(-1, 1)
	
	r1.b0.noise ~ dunif(0, 100)
	r1.b1.noise ~ dunif(0, 100)
	
	
	# setting up random effects 2
	
	for (j in 1:r2.cluster.n) {
	
		r2.B[j,1:r2.p] ~ dmnorm(r2.B.hat[j,], r2.B.tau[,])
	
		r2.b0[j] <- r2.B[j,1]
		r2.b1[j] <- r2.B[j,2]
	
		for(k in 1:r2.p) {   r2.B.hat[j,k] <- 0   }

		}

	# model correlation between random effects

	r2.B.tau[1:r2.p,1:r2.p] <- inverse(r2.B.noise[,])

	r2.B.noise[1,1] <- pow(r2.b0.noise, 2)
	r2.B.noise[2,2] <- pow(r2.b1.noise, 2)

	r2.B.noise[1,2] <- r2.rho * r2.b0.noise * r2.b1.noise
	r2.B.noise[2,1] <- r2.rho * r2.b0.noise * r2.b1.noise	

	r2.rho ~ dunif(-1, 1)

	r2.b0.noise ~ dunif(0, 100)
	r2.b1.noise ~ dunif(0, 100)
	
	
	# priors for fixed effects
	
	for (f in 1:P) {   b[f] ~ dnorm(0, .0001)   }

}